@@ -1,3 +1,4 @@
+
 /*
  * Copyright (c) 2014-2017, Nils Christopher Brause
  * All rights reserved.
@@ -28,6 +29,7 @@
 
 #include <algorithm>
 #include <memory>
+#include <string>
 #include <typeinfo>
 #include <utility>
 #include <vector>
@@ -154,7 +156,7 @@ namespace wayland
       {
       }
 
-      std::shared_ptr<native_t> ref_ptr()
+      std::shared_ptr<native_t> ref_ptr() const
       {
         return object;
       }
@@ -410,7 +412,7 @@ namespace wayland
       argument_t(const std::string &s);
 
       // handles objects
-      argument_t(const proxy_t &p);
+      argument_t(wl_object *o);
 
       // handles arrays
       argument_t(array_t a);
